@@ -323,7 +323,7 @@ def _post_match(parser, parser_args, args_values, arg):
 def _exec_module(path, exec_conf, args_values):
     """Load and execute a function of a module according to **exec_conf**."""
     mdl_func = exec_conf.get('function', 'main')
-    mdl_tree = exec_conf['module'].replace('-', '_')
+    mdl_tree = exec_conf['module']
 
     try:
         mdl = importlib.import_module(mdl_tree)
